@@ -22,6 +22,7 @@ from . import groundstate
 from . import rotate_spin
 from . import topology
 from . import ldos
+from . import bandstructure
 from . import increase_hilbert
 from .meanfield import Vinteraction
 from .sctk import dvector
@@ -219,7 +220,10 @@ class Hamiltonian():
         return atomicmultildos.get_density(self,**kwargs)
     def get_bands(self,**kwargs):
       """ Returns a figure with the bandstructure"""
-      return get_bands_nd(self,**kwargs)
+      return bandstructure.get_bands_nd(self,**kwargs)
+    def get_bands_map(self,**kwargs):
+      """ Returns a figure with the bandstructure"""
+      return bandstructure.get_bands_map(self,**kwargs)
     def get_kdos_bands(self,**kwargs):
         from .kdos import kdos_bands
         return kdos_bands(self,**kwargs)
@@ -394,8 +398,11 @@ class Hamiltonian():
         return MultiHopping(self.get_dict())
 
     @get_docstring(Vinteraction)
-    def get_mean_field_hamiltonian(self,**kwargs):
-        return Vinteraction(self,**kwargs).hamiltonian
+    def get_mean_field_hamiltonian(self,return_total_energy=False,**kwargs):
+        scf = Vinteraction(self,**kwargs)
+        if return_total_energy:
+            return (scf.hamiltonian,scf.total_energy)
+        else: return scf.hamiltonian
     def copy(self):
         """
         Return a copy of the hamiltonian
@@ -556,9 +563,9 @@ class Hamiltonian():
         from . import operatorlist
         return operators.object2operator(operatorlist.get_operator(self,name,
             **kwargs))
-    def extract(self,name): 
+    def extract(self,name,**kwargs): 
         """Extract something from the Hamiltonian"""
-        return extract.extract_from_hamiltonian(self,name)
+        return extract.extract_from_hamiltonian(self,name,**kwargs)
     @get_docstring(dvector.dvector_non_unitarity_map)
     def write_non_unitarity(self,**kwargs):
         dvector.dvector_non_unitarity_map(self,**kwargs)
